#!/bin/sh

#Edit this file in TextEdit, filling your input/output directory names below and commandline
#options, then doubleclick on it in Finder - it will run. For each file in input directory, a
#file with the same name and extension specified via "outputextension=" below will be created 
#in the output directory. It's OK to have input directory and output directory be the same.
#
#For all questions please contact support@scene-detector.com

#ENTER FULL PATH, not relative one!
inputdir="/tmp/indir/"
outdir="/tmp/outdir/"
options="--cpus=2 --outputtype fcp --marker-prefix=AutoScene"
    #commandline options for sd-cmdline-onefile to use. Do not use double quotes!
outputextension=".xml" 
    #extension to append to output files


#do not edit anything below
bindir=`dirname $0`
[ $bindir = '.' ] && bindir=`pwd`

if [ ! -r "${bindir}/../Scene Detector Pro.app" ]; then 

    [ -z "${SCENE_DETECTOR_PRO_ROOT}" ] || { #the var is non-empty
	bindir="${SCENE_DETECTOR_PRO_ROOT}"/commandline-interface
	[ -r "${bindir}" ] || { #wrong value
	    echo Can not open "$bindir" folder. Please update env variable SCENE_DETECTOR_PRO_ROOT.
	    exit 4
	}
    }

    [ -z "${SCENE_DETECTOR_PRO_ROOT}" ] && { #the var is empty
	echo Please set the env variable SCENE_DETECTOR_PRO_ROOT to the full path of the folder where "Scene Detector Pro" bundle resides.
	exit 3
    }
fi

cd "$inputdir"

[ -d "$inputdir" ] || { echo "error: path for input dir $inputdir does not exist or is not absolute. Aborting."; exit 1; }
[ -d "$outdir" ] || { echo "error: path for output dir $outdir does not exist or is not absolute. Aborting."; exit 1; }

echo starting detection in directory $inputdir at `date`
for f in * ; do
    echo processing $f
    outfn=$f
    #comment out next line if you need extension to be present (i.e. aa.mov becoming aa.mov.csv, not aa.csv)
    outfn=`echo $outfn | sed -e 's/\.[^.]*$//g'`
    "$bindir/sd-cmdline-onefile" $options "$inputdir/$f" "$outdir/${outfn}"${outputextension}
done
echo finished processing all files inside $inputdir at `date`
echo Thank you for using scene-detector.com software!
